summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
Diffstat (limited to 'plugins/jetpack/modules/protect.php')
-rw-r--r--plugins/jetpack/modules/protect.php10
1 files changed, 8 insertions, 2 deletions
diff --git a/plugins/jetpack/modules/protect.php b/plugins/jetpack/modules/protect.php
index 48117d5e..c2e60705 100644
--- a/plugins/jetpack/modules/protect.php
+++ b/plugins/jetpack/modules/protect.php
@@ -1,7 +1,7 @@
<?php
/**
* Module Name: Protect
- * Module Description: Block suspicious-looking sign in activity
+ * Module Description: Protect yourself from brute force and distributed brute force attacks, which are the most common way for hackers to get into your site.
* Sort Order: 1
* Recommendation Order: 4
* First Introduced: 3.4
@@ -9,7 +9,7 @@
* Auto Activate: Yes
* Module Tags: Recommended
* Feature: Security
* Additional Search Queries: security, secure, protection, botnet, brute force, protect, login
*/
include_once JETPACK__PLUGIN_DIR . 'modules/protect/shared-functions.php';
@@ -60,6 +60,12 @@ class Jetpack_Protect_Module {
// This is a backup in case $pagenow fails for some reason
add_action( 'login_form', array ( $this, 'check_login_ability' ), 1 );
+ // Load math fallback after math page form submission
+ if ( isset( $_POST[ 'jetpack_protect_process_math_form' ] ) ) {
+ include_once dirname( __FILE__ ) . '/protect/math-fallback.php';
+ new Jetpack_Protect_Math_Authenticate;
+ }
+
// Runs a script every day to clean up expired transients so they don't
// clog up our users' databases
require_once( JETPACK__PLUGIN_DIR . '/modules/protect/transient-cleanup.php' );
@@ -9,7 +9,7 @@
* Module Tags: Recommended
* Feature: Security
- * Additional Search Queries: security, secure, protection, botnet, brute force, protect, login
+ * Additional Search Queries: security, jetpack protect, secure, protection, botnet, brute force, protect, login, bot, password, passwords, strong passwords, strong password, wp-login.php, protect admin
*/
include_once JETPACK__PLUGIN_DIR . 'modules/protect/shared-functions.php';